# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmBuShortTermForecastGenerateProgressTopicBuForecastModification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmBuShortTermForecastGenerateProgressTopicBuForecastModification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'start_interval_index': 'int',
            'end_interval_index': 'int',
            'metric': 'str',
            'legacy_metric': 'str',
            'value': 'float',
            'values': 'list[WfmBuShortTermForecastGenerateProgressTopicModificationIntervalOffsetValue]',
            'enabled': 'bool',
            'granularity': 'str',
            'display_granularity': 'str',
            'planning_group_ids': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'start_interval_index': 'startIntervalIndex',
            'end_interval_index': 'endIntervalIndex',
            'metric': 'metric',
            'legacy_metric': 'legacyMetric',
            'value': 'value',
            'values': 'values',
            'enabled': 'enabled',
            'granularity': 'granularity',
            'display_granularity': 'displayGranularity',
            'planning_group_ids': 'planningGroupIds'
        }

        self._type = None
        self._start_interval_index = None
        self._end_interval_index = None
        self._metric = None
        self._legacy_metric = None
        self._value = None
        self._values = None
        self._enabled = None
        self._granularity = None
        self._display_granularity = None
        self._planning_group_ids = None

    @property
    def type(self):
        """
        Gets the type of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The type of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param type: The type of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: str
        """
        allowed_values = ["MinimumPerInterval", "MaximumPerInterval", "SetValuePerInterval", "ChangeValuePerInterval", "ChangePercentPerInterval", "SetValueOverRange", "ChangeValueOverRange", "SetValuesForIntervalSet"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def start_interval_index(self):
        """
        Gets the start_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The start_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: int
        """
        return self._start_interval_index

    @start_interval_index.setter
    def start_interval_index(self, start_interval_index):
        """
        Sets the start_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param start_interval_index: The start_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: int
        """
        
        self._start_interval_index = start_interval_index

    @property
    def end_interval_index(self):
        """
        Gets the end_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The end_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: int
        """
        return self._end_interval_index

    @end_interval_index.setter
    def end_interval_index(self, end_interval_index):
        """
        Sets the end_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param end_interval_index: The end_interval_index of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: int
        """
        
        self._end_interval_index = end_interval_index

    @property
    def metric(self):
        """
        Gets the metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param metric: The metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: str
        """
        allowed_values = ["Offered", "AverageHandleTimeSeconds"]
        if metric.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for metric -> " + metric)
            self._metric = "outdated_sdk_version"
        else:
            self._metric = metric

    @property
    def legacy_metric(self):
        """
        Gets the legacy_metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The legacy_metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: str
        """
        return self._legacy_metric

    @legacy_metric.setter
    def legacy_metric(self, legacy_metric):
        """
        Sets the legacy_metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param legacy_metric: The legacy_metric of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: str
        """
        allowed_values = ["AverageAfterCallWorkTimeSeconds", "AverageHandleTimeSeconds", "AverageTalkTimeSeconds", "Offered"]
        if legacy_metric.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for legacy_metric -> " + legacy_metric)
            self._legacy_metric = "outdated_sdk_version"
        else:
            self._legacy_metric = legacy_metric

    @property
    def value(self):
        """
        Gets the value of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The value of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param value: The value of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: float
        """
        
        self._value = value

    @property
    def values(self):
        """
        Gets the values of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The values of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: list[WfmBuShortTermForecastGenerateProgressTopicModificationIntervalOffsetValue]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param values: The values of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: list[WfmBuShortTermForecastGenerateProgressTopicModificationIntervalOffsetValue]
        """
        
        self._values = values

    @property
    def enabled(self):
        """
        Gets the enabled of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The enabled of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param enabled: The enabled of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def granularity(self):
        """
        Gets the granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """
        Sets the granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param granularity: The granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: str
        """
        
        self._granularity = granularity

    @property
    def display_granularity(self):
        """
        Gets the display_granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The display_granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: str
        """
        return self._display_granularity

    @display_granularity.setter
    def display_granularity(self, display_granularity):
        """
        Sets the display_granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param display_granularity: The display_granularity of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: str
        """
        
        self._display_granularity = display_granularity

    @property
    def planning_group_ids(self):
        """
        Gets the planning_group_ids of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :return: The planning_group_ids of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :rtype: list[str]
        """
        return self._planning_group_ids

    @planning_group_ids.setter
    def planning_group_ids(self, planning_group_ids):
        """
        Sets the planning_group_ids of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.


        :param planning_group_ids: The planning_group_ids of this WfmBuShortTermForecastGenerateProgressTopicBuForecastModification.
        :type: list[str]
        """
        
        self._planning_group_ids = planning_group_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ForecastPlanningGroupData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ForecastPlanningGroupData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'planning_group_id': 'str',
            'offered_per_interval': 'list[float]',
            'average_handle_time_seconds_per_interval': 'list[float]'
        }

        self.attribute_map = {
            'planning_group_id': 'planningGroupId',
            'offered_per_interval': 'offeredPerInterval',
            'average_handle_time_seconds_per_interval': 'averageHandleTimeSecondsPerInterval'
        }

        self._planning_group_id = None
        self._offered_per_interval = None
        self._average_handle_time_seconds_per_interval = None

    @property
    def planning_group_id(self):
        """
        Gets the planning_group_id of this ForecastPlanningGroupData.
        The ID of the planning group to which this data applies. Note this is a snapshot of the planning group at the time of forecast creation and may not correspond to the current configuration

        :return: The planning_group_id of this ForecastPlanningGroupData.
        :rtype: str
        """
        return self._planning_group_id

    @planning_group_id.setter
    def planning_group_id(self, planning_group_id):
        """
        Sets the planning_group_id of this ForecastPlanningGroupData.
        The ID of the planning group to which this data applies. Note this is a snapshot of the planning group at the time of forecast creation and may not correspond to the current configuration

        :param planning_group_id: The planning_group_id of this ForecastPlanningGroupData.
        :type: str
        """
        
        self._planning_group_id = planning_group_id

    @property
    def offered_per_interval(self):
        """
        Gets the offered_per_interval of this ForecastPlanningGroupData.
        Forecast offered counts per interval for this week of the forecast

        :return: The offered_per_interval of this ForecastPlanningGroupData.
        :rtype: list[float]
        """
        return self._offered_per_interval

    @offered_per_interval.setter
    def offered_per_interval(self, offered_per_interval):
        """
        Sets the offered_per_interval of this ForecastPlanningGroupData.
        Forecast offered counts per interval for this week of the forecast

        :param offered_per_interval: The offered_per_interval of this ForecastPlanningGroupData.
        :type: list[float]
        """
        
        self._offered_per_interval = offered_per_interval

    @property
    def average_handle_time_seconds_per_interval(self):
        """
        Gets the average_handle_time_seconds_per_interval of this ForecastPlanningGroupData.
        Forecast average handle time per interval in seconds

        :return: The average_handle_time_seconds_per_interval of this ForecastPlanningGroupData.
        :rtype: list[float]
        """
        return self._average_handle_time_seconds_per_interval

    @average_handle_time_seconds_per_interval.setter
    def average_handle_time_seconds_per_interval(self, average_handle_time_seconds_per_interval):
        """
        Sets the average_handle_time_seconds_per_interval of this ForecastPlanningGroupData.
        Forecast average handle time per interval in seconds

        :param average_handle_time_seconds_per_interval: The average_handle_time_seconds_per_interval of this ForecastPlanningGroupData.
        :type: list[float]
        """
        
        self._average_handle_time_seconds_per_interval = average_handle_time_seconds_per_interval

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationVideoEventTopicScreenshare(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationVideoEventTopicScreenshare - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'pcSelf': 'QueueConversationVideoEventTopicAddress',
            'id': 'str',
            'context': 'str',
            'sharing': 'bool',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'disconnect_type': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'wrapup': 'QueueConversationVideoEventTopicWrapup',
            'after_call_work': 'QueueConversationVideoEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'pcSelf': 'self',
            'id': 'id',
            'context': 'context',
            'sharing': 'sharing',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'disconnect_type': 'disconnectType',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._pcSelf = None
        self._id = None
        self._context = None
        self._sharing = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._disconnect_type = None
        self._connected_time = None
        self._disconnected_time = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this QueueConversationVideoEventTopicScreenshare.


        :return: The state of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationVideoEventTopicScreenshare.


        :param state: The state of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this QueueConversationVideoEventTopicScreenshare.


        :return: The pcSelf of this QueueConversationVideoEventTopicScreenshare.
        :rtype: QueueConversationVideoEventTopicAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this QueueConversationVideoEventTopicScreenshare.


        :param pcSelf: The pcSelf of this QueueConversationVideoEventTopicScreenshare.
        :type: QueueConversationVideoEventTopicAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def id(self):
        """
        Gets the id of this QueueConversationVideoEventTopicScreenshare.


        :return: The id of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationVideoEventTopicScreenshare.


        :param id: The id of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        
        self._id = id

    @property
    def context(self):
        """
        Gets the context of this QueueConversationVideoEventTopicScreenshare.


        :return: The context of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this QueueConversationVideoEventTopicScreenshare.


        :param context: The context of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        
        self._context = context

    @property
    def sharing(self):
        """
        Gets the sharing of this QueueConversationVideoEventTopicScreenshare.


        :return: The sharing of this QueueConversationVideoEventTopicScreenshare.
        :rtype: bool
        """
        return self._sharing

    @sharing.setter
    def sharing(self, sharing):
        """
        Sets the sharing of this QueueConversationVideoEventTopicScreenshare.


        :param sharing: The sharing of this QueueConversationVideoEventTopicScreenshare.
        :type: bool
        """
        
        self._sharing = sharing

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationVideoEventTopicScreenshare.


        :return: The provider of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationVideoEventTopicScreenshare.


        :param provider: The provider of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationVideoEventTopicScreenshare.


        :return: The script_id of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationVideoEventTopicScreenshare.


        :param script_id: The script_id of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationVideoEventTopicScreenshare.


        :return: The peer_id of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationVideoEventTopicScreenshare.


        :param peer_id: The peer_id of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationVideoEventTopicScreenshare.


        :return: The disconnect_type of this QueueConversationVideoEventTopicScreenshare.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationVideoEventTopicScreenshare.


        :param disconnect_type: The disconnect_type of this QueueConversationVideoEventTopicScreenshare.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationVideoEventTopicScreenshare.


        :return: The connected_time of this QueueConversationVideoEventTopicScreenshare.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationVideoEventTopicScreenshare.


        :param connected_time: The connected_time of this QueueConversationVideoEventTopicScreenshare.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationVideoEventTopicScreenshare.


        :return: The disconnected_time of this QueueConversationVideoEventTopicScreenshare.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationVideoEventTopicScreenshare.


        :param disconnected_time: The disconnected_time of this QueueConversationVideoEventTopicScreenshare.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationVideoEventTopicScreenshare.


        :return: The wrapup of this QueueConversationVideoEventTopicScreenshare.
        :rtype: QueueConversationVideoEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationVideoEventTopicScreenshare.


        :param wrapup: The wrapup of this QueueConversationVideoEventTopicScreenshare.
        :type: QueueConversationVideoEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationVideoEventTopicScreenshare.


        :return: The after_call_work of this QueueConversationVideoEventTopicScreenshare.
        :rtype: QueueConversationVideoEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationVideoEventTopicScreenshare.


        :param after_call_work: The after_call_work of this QueueConversationVideoEventTopicScreenshare.
        :type: QueueConversationVideoEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationVideoEventTopicScreenshare.


        :return: The after_call_work_required of this QueueConversationVideoEventTopicScreenshare.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationVideoEventTopicScreenshare.


        :param after_call_work_required: The after_call_work_required of this QueueConversationVideoEventTopicScreenshare.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationVideoEventTopicScreenshare.


        :return: The additional_properties of this QueueConversationVideoEventTopicScreenshare.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationVideoEventTopicScreenshare.


        :param additional_properties: The additional_properties of this QueueConversationVideoEventTopicScreenshare.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class IntradayPerformancePredictionData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntradayPerformancePredictionData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'service_level_percent': 'float',
            'average_speed_of_answer_seconds': 'float',
            'occupancy_percent': 'float'
        }

        self.attribute_map = {
            'service_level_percent': 'serviceLevelPercent',
            'average_speed_of_answer_seconds': 'averageSpeedOfAnswerSeconds',
            'occupancy_percent': 'occupancyPercent'
        }

        self._service_level_percent = None
        self._average_speed_of_answer_seconds = None
        self._occupancy_percent = None

    @property
    def service_level_percent(self):
        """
        Gets the service_level_percent of this IntradayPerformancePredictionData.
        Percentage of interactions that meets service level target as defined in the matching service goal templates

        :return: The service_level_percent of this IntradayPerformancePredictionData.
        :rtype: float
        """
        return self._service_level_percent

    @service_level_percent.setter
    def service_level_percent(self, service_level_percent):
        """
        Sets the service_level_percent of this IntradayPerformancePredictionData.
        Percentage of interactions that meets service level target as defined in the matching service goal templates

        :param service_level_percent: The service_level_percent of this IntradayPerformancePredictionData.
        :type: float
        """
        
        self._service_level_percent = service_level_percent

    @property
    def average_speed_of_answer_seconds(self):
        """
        Gets the average_speed_of_answer_seconds of this IntradayPerformancePredictionData.
        Predicted average time in seconds it takes to answer an interaction once the interaction becomes available to be routed

        :return: The average_speed_of_answer_seconds of this IntradayPerformancePredictionData.
        :rtype: float
        """
        return self._average_speed_of_answer_seconds

    @average_speed_of_answer_seconds.setter
    def average_speed_of_answer_seconds(self, average_speed_of_answer_seconds):
        """
        Sets the average_speed_of_answer_seconds of this IntradayPerformancePredictionData.
        Predicted average time in seconds it takes to answer an interaction once the interaction becomes available to be routed

        :param average_speed_of_answer_seconds: The average_speed_of_answer_seconds of this IntradayPerformancePredictionData.
        :type: float
        """
        
        self._average_speed_of_answer_seconds = average_speed_of_answer_seconds

    @property
    def occupancy_percent(self):
        """
        Gets the occupancy_percent of this IntradayPerformancePredictionData.
        Percentage of on-queue time for all agents in this group that are occupied handling interactions

        :return: The occupancy_percent of this IntradayPerformancePredictionData.
        :rtype: float
        """
        return self._occupancy_percent

    @occupancy_percent.setter
    def occupancy_percent(self, occupancy_percent):
        """
        Sets the occupancy_percent of this IntradayPerformancePredictionData.
        Percentage of on-queue time for all agents in this group that are occupied handling interactions

        :param occupancy_percent: The occupancy_percent of this IntradayPerformancePredictionData.
        :type: float
        """
        
        self._occupancy_percent = occupancy_percent

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContentAttachment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContentAttachment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'media_type': 'str',
            'url': 'str',
            'mime': 'str',
            'text': 'str',
            'sha256': 'str',
            'filename': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'media_type': 'mediaType',
            'url': 'url',
            'mime': 'mime',
            'text': 'text',
            'sha256': 'sha256',
            'filename': 'filename'
        }

        self._id = None
        self._media_type = None
        self._url = None
        self._mime = None
        self._text = None
        self._sha256 = None
        self._filename = None

    @property
    def id(self):
        """
        Gets the id of this ContentAttachment.
        Vendor specific ID for media. For example, a LINE sticker ID

        :return: The id of this ContentAttachment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContentAttachment.
        Vendor specific ID for media. For example, a LINE sticker ID

        :param id: The id of this ContentAttachment.
        :type: str
        """
        
        self._id = id

    @property
    def media_type(self):
        """
        Gets the media_type of this ContentAttachment.
        The type of media this instance represents

        :return: The media_type of this ContentAttachment.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this ContentAttachment.
        The type of media this instance represents

        :param media_type: The media_type of this ContentAttachment.
        :type: str
        """
        allowed_values = ["Image", "Video", "Audio", "File"]
        if media_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for media_type -> " + media_type)
            self._media_type = "outdated_sdk_version"
        else:
            self._media_type = media_type

    @property
    def url(self):
        """
        Gets the url of this ContentAttachment.
        Content element url

        :return: The url of this ContentAttachment.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this ContentAttachment.
        Content element url

        :param url: The url of this ContentAttachment.
        :type: str
        """
        
        self._url = url

    @property
    def mime(self):
        """
        Gets the mime of this ContentAttachment.
        Content mime type from https://www.iana.org/assignments/media-types/media-types.xhtml

        :return: The mime of this ContentAttachment.
        :rtype: str
        """
        return self._mime

    @mime.setter
    def mime(self, mime):
        """
        Sets the mime of this ContentAttachment.
        Content mime type from https://www.iana.org/assignments/media-types/media-types.xhtml

        :param mime: The mime of this ContentAttachment.
        :type: str
        """
        
        self._mime = mime

    @property
    def text(self):
        """
        Gets the text of this ContentAttachment.
        Text message associated with media element: e.g. caption in case of image.

        :return: The text of this ContentAttachment.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this ContentAttachment.
        Text message associated with media element: e.g. caption in case of image.

        :param text: The text of this ContentAttachment.
        :type: str
        """
        
        self._text = text

    @property
    def sha256(self):
        """
        Gets the sha256 of this ContentAttachment.
        Secure hash of the media content

        :return: The sha256 of this ContentAttachment.
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """
        Sets the sha256 of this ContentAttachment.
        Secure hash of the media content

        :param sha256: The sha256 of this ContentAttachment.
        :type: str
        """
        
        self._sha256 = sha256

    @property
    def filename(self):
        """
        Gets the filename of this ContentAttachment.
        Suggested file name for media file

        :return: The filename of this ContentAttachment.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this ContentAttachment.
        Suggested file name for media file

        :param filename: The filename of this ContentAttachment.
        :type: str
        """
        
        self._filename = filename

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Education(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Education - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'school': 'str',
            'field_of_study': 'str',
            'notes': 'str',
            'date_start': 'date',
            'date_end': 'date'
        }

        self.attribute_map = {
            'school': 'school',
            'field_of_study': 'fieldOfStudy',
            'notes': 'notes',
            'date_start': 'dateStart',
            'date_end': 'dateEnd'
        }

        self._school = None
        self._field_of_study = None
        self._notes = None
        self._date_start = None
        self._date_end = None

    @property
    def school(self):
        """
        Gets the school of this Education.


        :return: The school of this Education.
        :rtype: str
        """
        return self._school

    @school.setter
    def school(self, school):
        """
        Sets the school of this Education.


        :param school: The school of this Education.
        :type: str
        """
        
        self._school = school

    @property
    def field_of_study(self):
        """
        Gets the field_of_study of this Education.


        :return: The field_of_study of this Education.
        :rtype: str
        """
        return self._field_of_study

    @field_of_study.setter
    def field_of_study(self, field_of_study):
        """
        Sets the field_of_study of this Education.


        :param field_of_study: The field_of_study of this Education.
        :type: str
        """
        
        self._field_of_study = field_of_study

    @property
    def notes(self):
        """
        Gets the notes of this Education.
        Notes about education has a 2000 character limit

        :return: The notes of this Education.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this Education.
        Notes about education has a 2000 character limit

        :param notes: The notes of this Education.
        :type: str
        """
        
        self._notes = notes

    @property
    def date_start(self):
        """
        Gets the date_start of this Education.
        Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_start of this Education.
        :rtype: date
        """
        return self._date_start

    @date_start.setter
    def date_start(self, date_start):
        """
        Sets the date_start of this Education.
        Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_start: The date_start of this Education.
        :type: date
        """
        
        self._date_start = date_start

    @property
    def date_end(self):
        """
        Gets the date_end of this Education.
        Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_end of this Education.
        :rtype: date
        """
        return self._date_end

    @date_end.setter
    def date_end(self, date_end):
        """
        Sets the date_end of this Education.
        Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_end: The date_end of this Education.
        :type: date
        """
        
        self._date_end = date_end

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TrustRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TrustRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'created_by': 'OrgUser',
            'date_created': 'datetime',
            'trustee': 'Organization',
            'users': 'list[OrgUser]',
            'groups': 'list[TrustGroup]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'created_by': 'createdBy',
            'date_created': 'dateCreated',
            'trustee': 'trustee',
            'users': 'users',
            'groups': 'groups',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._created_by = None
        self._date_created = None
        self._trustee = None
        self._users = None
        self._groups = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TrustRequest.
        The globally unique identifier for the object.

        :return: The id of this TrustRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TrustRequest.
        The globally unique identifier for the object.

        :param id: The id of this TrustRequest.
        :type: str
        """
        
        self._id = id

    @property
    def created_by(self):
        """
        Gets the created_by of this TrustRequest.
        User who created this request.

        :return: The created_by of this TrustRequest.
        :rtype: OrgUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this TrustRequest.
        User who created this request.

        :param created_by: The created_by of this TrustRequest.
        :type: OrgUser
        """
        
        self._created_by = created_by

    @property
    def date_created(self):
        """
        Gets the date_created of this TrustRequest.
        Date request was created. There is a 48 hour expiration on all requests. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this TrustRequest.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this TrustRequest.
        Date request was created. There is a 48 hour expiration on all requests. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this TrustRequest.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def trustee(self):
        """
        Gets the trustee of this TrustRequest.
        Trustee organization who generated this request.

        :return: The trustee of this TrustRequest.
        :rtype: Organization
        """
        return self._trustee

    @trustee.setter
    def trustee(self, trustee):
        """
        Sets the trustee of this TrustRequest.
        Trustee organization who generated this request.

        :param trustee: The trustee of this TrustRequest.
        :type: Organization
        """
        
        self._trustee = trustee

    @property
    def users(self):
        """
        Gets the users of this TrustRequest.
        The list of trustee users that are requesting access.

        :return: The users of this TrustRequest.
        :rtype: list[OrgUser]
        """
        return self._users

    @users.setter
    def users(self, users):
        """
        Sets the users of this TrustRequest.
        The list of trustee users that are requesting access.

        :param users: The users of this TrustRequest.
        :type: list[OrgUser]
        """
        
        self._users = users

    @property
    def groups(self):
        """
        Gets the groups of this TrustRequest.
        The list of trustee groups that are requesting access.

        :return: The groups of this TrustRequest.
        :rtype: list[TrustGroup]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """
        Sets the groups of this TrustRequest.
        The list of trustee groups that are requesting access.

        :param groups: The groups of this TrustRequest.
        :type: list[TrustGroup]
        """
        
        self._groups = groups

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TrustRequest.
        The URI for this object

        :return: The self_uri of this TrustRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TrustRequest.
        The URI for this object

        :param self_uri: The self_uri of this TrustRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WhatsAppIntegration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WhatsAppIntegration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'phone_number': 'str',
            'status': 'str',
            'recipient': 'DomainEntityRef',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'created_by': 'DomainEntityRef',
            'modified_by': 'DomainEntityRef',
            'version': 'int',
            'activation_status_code': 'str',
            'activation_error_info': 'ErrorBody',
            'create_status': 'str',
            'create_error': 'ErrorBody',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'phone_number': 'phoneNumber',
            'status': 'status',
            'recipient': 'recipient',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'created_by': 'createdBy',
            'modified_by': 'modifiedBy',
            'version': 'version',
            'activation_status_code': 'activationStatusCode',
            'activation_error_info': 'activationErrorInfo',
            'create_status': 'createStatus',
            'create_error': 'createError',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._phone_number = None
        self._status = None
        self._recipient = None
        self._date_created = None
        self._date_modified = None
        self._created_by = None
        self._modified_by = None
        self._version = None
        self._activation_status_code = None
        self._activation_error_info = None
        self._create_status = None
        self._create_error = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WhatsAppIntegration.
        A unique Integration Id.

        :return: The id of this WhatsAppIntegration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WhatsAppIntegration.
        A unique Integration Id.

        :param id: The id of this WhatsAppIntegration.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WhatsAppIntegration.
        The name of the WhatsApp integration.

        :return: The name of this WhatsAppIntegration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WhatsAppIntegration.
        The name of the WhatsApp integration.

        :param name: The name of this WhatsAppIntegration.
        :type: str
        """
        
        self._name = name

    @property
    def phone_number(self):
        """
        Gets the phone_number of this WhatsAppIntegration.
        The phone number associated to the whatsApp integration.

        :return: The phone_number of this WhatsAppIntegration.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this WhatsAppIntegration.
        The phone number associated to the whatsApp integration.

        :param phone_number: The phone_number of this WhatsAppIntegration.
        :type: str
        """
        
        self._phone_number = phone_number

    @property
    def status(self):
        """
        Gets the status of this WhatsAppIntegration.
        The status of the WhatsApp Integration

        :return: The status of this WhatsAppIntegration.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WhatsAppIntegration.
        The status of the WhatsApp Integration

        :param status: The status of this WhatsAppIntegration.
        :type: str
        """
        allowed_values = ["Active", "Inactive", "Error", "Starting", "Incomplete", "Deleting", "DeletionFailed"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def recipient(self):
        """
        Gets the recipient of this WhatsAppIntegration.
        The recipient associated to the WhatsApp Integration. This recipient is used to associate a flow to an integration

        :return: The recipient of this WhatsAppIntegration.
        :rtype: DomainEntityRef
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """
        Sets the recipient of this WhatsAppIntegration.
        The recipient associated to the WhatsApp Integration. This recipient is used to associate a flow to an integration

        :param recipient: The recipient of this WhatsAppIntegration.
        :type: DomainEntityRef
        """
        
        self._recipient = recipient

    @property
    def date_created(self):
        """
        Gets the date_created of this WhatsAppIntegration.
        Date this Integration was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this WhatsAppIntegration.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this WhatsAppIntegration.
        Date this Integration was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this WhatsAppIntegration.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this WhatsAppIntegration.
        Date this Integration was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this WhatsAppIntegration.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this WhatsAppIntegration.
        Date this Integration was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this WhatsAppIntegration.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def created_by(self):
        """
        Gets the created_by of this WhatsAppIntegration.
        User reference that created this Integration

        :return: The created_by of this WhatsAppIntegration.
        :rtype: DomainEntityRef
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this WhatsAppIntegration.
        User reference that created this Integration

        :param created_by: The created_by of this WhatsAppIntegration.
        :type: DomainEntityRef
        """
        
        self._created_by = created_by

    @property
    def modified_by(self):
        """
        Gets the modified_by of this WhatsAppIntegration.
        User reference that last modified this Integration

        :return: The modified_by of this WhatsAppIntegration.
        :rtype: DomainEntityRef
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this WhatsAppIntegration.
        User reference that last modified this Integration

        :param modified_by: The modified_by of this WhatsAppIntegration.
        :type: DomainEntityRef
        """
        
        self._modified_by = modified_by

    @property
    def version(self):
        """
        Gets the version of this WhatsAppIntegration.
        Version number required for updates.

        :return: The version of this WhatsAppIntegration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this WhatsAppIntegration.
        Version number required for updates.

        :param version: The version of this WhatsAppIntegration.
        :type: int
        """
        
        self._version = version

    @property
    def activation_status_code(self):
        """
        Gets the activation_status_code of this WhatsAppIntegration.
        The status code of WhatsApp Integration activation process

        :return: The activation_status_code of this WhatsAppIntegration.
        :rtype: str
        """
        return self._activation_status_code

    @activation_status_code.setter
    def activation_status_code(self, activation_status_code):
        """
        Sets the activation_status_code of this WhatsAppIntegration.
        The status code of WhatsApp Integration activation process

        :param activation_status_code: The activation_status_code of this WhatsAppIntegration.
        :type: str
        """
        allowed_values = ["CodeSent", "WaitRequired", "ActivationFailed", "CodeConfirmed", "ConfirmationFailed", "ResendCode"]
        if activation_status_code.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for activation_status_code -> " + activation_status_code)
            self._activation_status_code = "outdated_sdk_version"
        else:
            self._activation_status_code = activation_status_code

    @property
    def activation_error_info(self):
        """
        Gets the activation_error_info of this WhatsAppIntegration.
        The error information of WhatsApp Integration activation process

        :return: The activation_error_info of this WhatsAppIntegration.
        :rtype: ErrorBody
        """
        return self._activation_error_info

    @activation_error_info.setter
    def activation_error_info(self, activation_error_info):
        """
        Sets the activation_error_info of this WhatsAppIntegration.
        The error information of WhatsApp Integration activation process

        :param activation_error_info: The activation_error_info of this WhatsAppIntegration.
        :type: ErrorBody
        """
        
        self._activation_error_info = activation_error_info

    @property
    def create_status(self):
        """
        Gets the create_status of this WhatsAppIntegration.
        Status of asynchronous create operation

        :return: The create_status of this WhatsAppIntegration.
        :rtype: str
        """
        return self._create_status

    @create_status.setter
    def create_status(self, create_status):
        """
        Sets the create_status of this WhatsAppIntegration.
        Status of asynchronous create operation

        :param create_status: The create_status of this WhatsAppIntegration.
        :type: str
        """
        allowed_values = ["Initiated", "Completed", "Error"]
        if create_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for create_status -> " + create_status)
            self._create_status = "outdated_sdk_version"
        else:
            self._create_status = create_status

    @property
    def create_error(self):
        """
        Gets the create_error of this WhatsAppIntegration.
        Error information returned, if createStatus is set to Error

        :return: The create_error of this WhatsAppIntegration.
        :rtype: ErrorBody
        """
        return self._create_error

    @create_error.setter
    def create_error(self, create_error):
        """
        Sets the create_error of this WhatsAppIntegration.
        Error information returned, if createStatus is set to Error

        :param create_error: The create_error of this WhatsAppIntegration.
        :type: ErrorBody
        """
        
        self._create_error = create_error

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WhatsAppIntegration.
        The URI for this object

        :return: The self_uri of this WhatsAppIntegration.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WhatsAppIntegration.
        The URI for this object

        :param self_uri: The self_uri of this WhatsAppIntegration.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateSecureSession(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateSecureSession - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'source_participant_id': 'str',
            'flow_id': 'str',
            'user_data': 'str',
            'disconnect': 'bool'
        }

        self.attribute_map = {
            'source_participant_id': 'sourceParticipantId',
            'flow_id': 'flowId',
            'user_data': 'userData',
            'disconnect': 'disconnect'
        }

        self._source_participant_id = None
        self._flow_id = None
        self._user_data = None
        self._disconnect = None

    @property
    def source_participant_id(self):
        """
        Gets the source_participant_id of this CreateSecureSession.
        requesting participant

        :return: The source_participant_id of this CreateSecureSession.
        :rtype: str
        """
        return self._source_participant_id

    @source_participant_id.setter
    def source_participant_id(self, source_participant_id):
        """
        Sets the source_participant_id of this CreateSecureSession.
        requesting participant

        :param source_participant_id: The source_participant_id of this CreateSecureSession.
        :type: str
        """
        
        self._source_participant_id = source_participant_id

    @property
    def flow_id(self):
        """
        Gets the flow_id of this CreateSecureSession.
        the flow id to execute in the secure session

        :return: The flow_id of this CreateSecureSession.
        :rtype: str
        """
        return self._flow_id

    @flow_id.setter
    def flow_id(self, flow_id):
        """
        Sets the flow_id of this CreateSecureSession.
        the flow id to execute in the secure session

        :param flow_id: The flow_id of this CreateSecureSession.
        :type: str
        """
        
        self._flow_id = flow_id

    @property
    def user_data(self):
        """
        Gets the user_data of this CreateSecureSession.
        user data for the secure session

        :return: The user_data of this CreateSecureSession.
        :rtype: str
        """
        return self._user_data

    @user_data.setter
    def user_data(self, user_data):
        """
        Sets the user_data of this CreateSecureSession.
        user data for the secure session

        :param user_data: The user_data of this CreateSecureSession.
        :type: str
        """
        
        self._user_data = user_data

    @property
    def disconnect(self):
        """
        Gets the disconnect of this CreateSecureSession.
        if true, disconnect the agent after creating the session

        :return: The disconnect of this CreateSecureSession.
        :rtype: bool
        """
        return self._disconnect

    @disconnect.setter
    def disconnect(self, disconnect):
        """
        Sets the disconnect of this CreateSecureSession.
        if true, disconnect the agent after creating the session

        :param disconnect: The disconnect of this CreateSecureSession.
        :type: bool
        """
        
        self._disconnect = disconnect

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PatchActionTemplate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PatchActionTemplate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'media_type': 'str',
            'state': 'str',
            'content_offer': 'PatchContentOffer'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'media_type': 'mediaType',
            'state': 'state',
            'content_offer': 'contentOffer'
        }

        self._name = None
        self._description = None
        self._media_type = None
        self._state = None
        self._content_offer = None

    @property
    def name(self):
        """
        Gets the name of this PatchActionTemplate.
        Name of the action template.

        :return: The name of this PatchActionTemplate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PatchActionTemplate.
        Name of the action template.

        :param name: The name of this PatchActionTemplate.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this PatchActionTemplate.
        Description of the action template's functionality.

        :return: The description of this PatchActionTemplate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this PatchActionTemplate.
        Description of the action template's functionality.

        :param description: The description of this PatchActionTemplate.
        :type: str
        """
        
        self._description = description

    @property
    def media_type(self):
        """
        Gets the media_type of this PatchActionTemplate.
        Media type of action described by the action template.

        :return: The media_type of this PatchActionTemplate.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this PatchActionTemplate.
        Media type of action described by the action template.

        :param media_type: The media_type of this PatchActionTemplate.
        :type: str
        """
        allowed_values = ["webchat", "webMessagingOffer", "contentOffer", "integrationAction", "architectFlow"]
        if media_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for media_type -> " + media_type)
            self._media_type = "outdated_sdk_version"
        else:
            self._media_type = media_type

    @property
    def state(self):
        """
        Gets the state of this PatchActionTemplate.
        Whether the action template is currently active, inactive or deleted.

        :return: The state of this PatchActionTemplate.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this PatchActionTemplate.
        Whether the action template is currently active, inactive or deleted.

        :param state: The state of this PatchActionTemplate.
        :type: str
        """
        allowed_values = ["Active", "Inactive", "Deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def content_offer(self):
        """
        Gets the content_offer of this PatchActionTemplate.
        Properties used to configure an action of type content offer

        :return: The content_offer of this PatchActionTemplate.
        :rtype: PatchContentOffer
        """
        return self._content_offer

    @content_offer.setter
    def content_offer(self, content_offer):
        """
        Sets the content_offer of this PatchActionTemplate.
        Properties used to configure an action of type content offer

        :param content_offer: The content_offer of this PatchActionTemplate.
        :type: PatchContentOffer
        """
        
        self._content_offer = content_offer

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ExternalOrganizationTrustorLink(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ExternalOrganizationTrustorLink - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'external_organization_id': 'str',
            'trustor_org_id': 'str',
            'date_created': 'datetime',
            'external_organization_uri': 'str'
        }

        self.attribute_map = {
            'external_organization_id': 'externalOrganizationId',
            'trustor_org_id': 'trustorOrgId',
            'date_created': 'dateCreated',
            'external_organization_uri': 'externalOrganizationUri'
        }

        self._external_organization_id = None
        self._trustor_org_id = None
        self._date_created = None
        self._external_organization_uri = None

    @property
    def external_organization_id(self):
        """
        Gets the external_organization_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud External Organization entity in the External Contacts system that will be used to represent the trustor org

        :return: The external_organization_id of this ExternalOrganizationTrustorLink.
        :rtype: str
        """
        return self._external_organization_id

    @external_organization_id.setter
    def external_organization_id(self, external_organization_id):
        """
        Sets the external_organization_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud External Organization entity in the External Contacts system that will be used to represent the trustor org

        :param external_organization_id: The external_organization_id of this ExternalOrganizationTrustorLink.
        :type: str
        """
        
        self._external_organization_id = external_organization_id

    @property
    def trustor_org_id(self):
        """
        Gets the trustor_org_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud organization that has granted trust to this PureCloud organization

        :return: The trustor_org_id of this ExternalOrganizationTrustorLink.
        :rtype: str
        """
        return self._trustor_org_id

    @trustor_org_id.setter
    def trustor_org_id(self, trustor_org_id):
        """
        Sets the trustor_org_id of this ExternalOrganizationTrustorLink.
        The id of a PureCloud organization that has granted trust to this PureCloud organization

        :param trustor_org_id: The trustor_org_id of this ExternalOrganizationTrustorLink.
        :type: str
        """
        
        self._trustor_org_id = trustor_org_id

    @property
    def date_created(self):
        """
        Gets the date_created of this ExternalOrganizationTrustorLink.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this ExternalOrganizationTrustorLink.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ExternalOrganizationTrustorLink.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this ExternalOrganizationTrustorLink.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def external_organization_uri(self):
        """
        Gets the external_organization_uri of this ExternalOrganizationTrustorLink.
        The URI for the External Organization that is linked to the trustor org

        :return: The external_organization_uri of this ExternalOrganizationTrustorLink.
        :rtype: str
        """
        return self._external_organization_uri

    @external_organization_uri.setter
    def external_organization_uri(self, external_organization_uri):
        """
        Sets the external_organization_uri of this ExternalOrganizationTrustorLink.
        The URI for the External Organization that is linked to the trustor org

        :param external_organization_uri: The external_organization_uri of this ExternalOrganizationTrustorLink.
        :type: str
        """
        
        self._external_organization_uri = external_organization_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AcwSettings(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AcwSettings - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'wrapup_prompt': 'str',
            'timeout_ms': 'int'
        }

        self.attribute_map = {
            'wrapup_prompt': 'wrapupPrompt',
            'timeout_ms': 'timeoutMs'
        }

        self._wrapup_prompt = None
        self._timeout_ms = None

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this AcwSettings.
        This field controls how the UI prompts the agent for a wrapup.

        :return: The wrapup_prompt of this AcwSettings.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this AcwSettings.
        This field controls how the UI prompts the agent for a wrapup.

        :param wrapup_prompt: The wrapup_prompt of this AcwSettings.
        :type: str
        """
        allowed_values = ["MANDATORY", "OPTIONAL", "MANDATORY_TIMEOUT", "MANDATORY_FORCED_TIMEOUT", "AGENT_REQUESTED"]
        if wrapup_prompt.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for wrapup_prompt -> " + wrapup_prompt)
            self._wrapup_prompt = "outdated_sdk_version"
        else:
            self._wrapup_prompt = wrapup_prompt

    @property
    def timeout_ms(self):
        """
        Gets the timeout_ms of this AcwSettings.
        The amount of time the agent can stay in ACW (Min: 1 sec, Max: 1 day).  Can only be used when ACW is MANDATORY_TIMEOUT or MANDATORY_FORCED_TIMEOUT.

        :return: The timeout_ms of this AcwSettings.
        :rtype: int
        """
        return self._timeout_ms

    @timeout_ms.setter
    def timeout_ms(self, timeout_ms):
        """
        Sets the timeout_ms of this AcwSettings.
        The amount of time the agent can stay in ACW (Min: 1 sec, Max: 1 day).  Can only be used when ACW is MANDATORY_TIMEOUT or MANDATORY_FORCED_TIMEOUT.

        :param timeout_ms: The timeout_ms of this AcwSettings.
        :type: int
        """
        
        self._timeout_ms = timeout_ms

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AsyncConversationQuery(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AsyncConversationQuery - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'conversation_filters': 'list[ConversationDetailQueryFilter]',
            'segment_filters': 'list[SegmentDetailQueryFilter]',
            'evaluation_filters': 'list[EvaluationDetailQueryFilter]',
            'media_endpoint_stat_filters': 'list[MediaEndpointStatDetailQueryFilter]',
            'survey_filters': 'list[SurveyDetailQueryFilter]',
            'resolution_filters': 'list[ResolutionDetailQueryFilter]',
            'order': 'str',
            'order_by': 'str',
            'interval': 'str',
            'limit': 'int',
            'start_of_day_interval_matching': 'bool'
        }

        self.attribute_map = {
            'conversation_filters': 'conversationFilters',
            'segment_filters': 'segmentFilters',
            'evaluation_filters': 'evaluationFilters',
            'media_endpoint_stat_filters': 'mediaEndpointStatFilters',
            'survey_filters': 'surveyFilters',
            'resolution_filters': 'resolutionFilters',
            'order': 'order',
            'order_by': 'orderBy',
            'interval': 'interval',
            'limit': 'limit',
            'start_of_day_interval_matching': 'startOfDayIntervalMatching'
        }

        self._conversation_filters = None
        self._segment_filters = None
        self._evaluation_filters = None
        self._media_endpoint_stat_filters = None
        self._survey_filters = None
        self._resolution_filters = None
        self._order = None
        self._order_by = None
        self._interval = None
        self._limit = None
        self._start_of_day_interval_matching = None

    @property
    def conversation_filters(self):
        """
        Gets the conversation_filters of this AsyncConversationQuery.
        Filters that target conversation-level data

        :return: The conversation_filters of this AsyncConversationQuery.
        :rtype: list[ConversationDetailQueryFilter]
        """
        return self._conversation_filters

    @conversation_filters.setter
    def conversation_filters(self, conversation_filters):
        """
        Sets the conversation_filters of this AsyncConversationQuery.
        Filters that target conversation-level data

        :param conversation_filters: The conversation_filters of this AsyncConversationQuery.
        :type: list[ConversationDetailQueryFilter]
        """
        
        self._conversation_filters = conversation_filters

    @property
    def segment_filters(self):
        """
        Gets the segment_filters of this AsyncConversationQuery.
        Filters that target individual segments within a conversation

        :return: The segment_filters of this AsyncConversationQuery.
        :rtype: list[SegmentDetailQueryFilter]
        """
        return self._segment_filters

    @segment_filters.setter
    def segment_filters(self, segment_filters):
        """
        Sets the segment_filters of this AsyncConversationQuery.
        Filters that target individual segments within a conversation

        :param segment_filters: The segment_filters of this AsyncConversationQuery.
        :type: list[SegmentDetailQueryFilter]
        """
        
        self._segment_filters = segment_filters

    @property
    def evaluation_filters(self):
        """
        Gets the evaluation_filters of this AsyncConversationQuery.
        Filters that target evaluations

        :return: The evaluation_filters of this AsyncConversationQuery.
        :rtype: list[EvaluationDetailQueryFilter]
        """
        return self._evaluation_filters

    @evaluation_filters.setter
    def evaluation_filters(self, evaluation_filters):
        """
        Sets the evaluation_filters of this AsyncConversationQuery.
        Filters that target evaluations

        :param evaluation_filters: The evaluation_filters of this AsyncConversationQuery.
        :type: list[EvaluationDetailQueryFilter]
        """
        
        self._evaluation_filters = evaluation_filters

    @property
    def media_endpoint_stat_filters(self):
        """
        Gets the media_endpoint_stat_filters of this AsyncConversationQuery.
        Filters that target mediaEndpointStats

        :return: The media_endpoint_stat_filters of this AsyncConversationQuery.
        :rtype: list[MediaEndpointStatDetailQueryFilter]
        """
        return self._media_endpoint_stat_filters

    @media_endpoint_stat_filters.setter
    def media_endpoint_stat_filters(self, media_endpoint_stat_filters):
        """
        Sets the media_endpoint_stat_filters of this AsyncConversationQuery.
        Filters that target mediaEndpointStats

        :param media_endpoint_stat_filters: The media_endpoint_stat_filters of this AsyncConversationQuery.
        :type: list[MediaEndpointStatDetailQueryFilter]
        """
        
        self._media_endpoint_stat_filters = media_endpoint_stat_filters

    @property
    def survey_filters(self):
        """
        Gets the survey_filters of this AsyncConversationQuery.
        Filters that target surveys

        :return: The survey_filters of this AsyncConversationQuery.
        :rtype: list[SurveyDetailQueryFilter]
        """
        return self._survey_filters

    @survey_filters.setter
    def survey_filters(self, survey_filters):
        """
        Sets the survey_filters of this AsyncConversationQuery.
        Filters that target surveys

        :param survey_filters: The survey_filters of this AsyncConversationQuery.
        :type: list[SurveyDetailQueryFilter]
        """
        
        self._survey_filters = survey_filters

    @property
    def resolution_filters(self):
        """
        Gets the resolution_filters of this AsyncConversationQuery.
        Filters that target resolutions

        :return: The resolution_filters of this AsyncConversationQuery.
        :rtype: list[ResolutionDetailQueryFilter]
        """
        return self._resolution_filters

    @resolution_filters.setter
    def resolution_filters(self, resolution_filters):
        """
        Sets the resolution_filters of this AsyncConversationQuery.
        Filters that target resolutions

        :param resolution_filters: The resolution_filters of this AsyncConversationQuery.
        :type: list[ResolutionDetailQueryFilter]
        """
        
        self._resolution_filters = resolution_filters

    @property
    def order(self):
        """
        Gets the order of this AsyncConversationQuery.
        Sort the result set in ascending/descending order. Default is ascending

        :return: The order of this AsyncConversationQuery.
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this AsyncConversationQuery.
        Sort the result set in ascending/descending order. Default is ascending

        :param order: The order of this AsyncConversationQuery.
        :type: str
        """
        allowed_values = ["asc", "desc"]
        if order.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for order -> " + order)
            self._order = "outdated_sdk_version"
        else:
            self._order = order

    @property
    def order_by(self):
        """
        Gets the order_by of this AsyncConversationQuery.
        Specify which data element within the result set to use for sorting. The options  to use as a basis for sorting the results: conversationStart, segmentStart, and segmentEnd. If not specified, the default is conversationStart

        :return: The order_by of this AsyncConversationQuery.
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """
        Sets the order_by of this AsyncConversationQuery.
        Specify which data element within the result set to use for sorting. The options  to use as a basis for sorting the results: conversationStart, segmentStart, and segmentEnd. If not specified, the default is conversationStart

        :param order_by: The order_by of this AsyncConversationQuery.
        :type: str
        """
        allowed_values = ["conversationStart", "conversationEnd", "segmentStart", "segmentEnd"]
        if order_by.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for order_by -> " + order_by)
            self._order_by = "outdated_sdk_version"
        else:
            self._order_by = order_by

    @property
    def interval(self):
        """
        Gets the interval of this AsyncConversationQuery.
        Specifies the date and time range of data being queried. Results will include all conversations that had activity during the interval. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this AsyncConversationQuery.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this AsyncConversationQuery.
        Specifies the date and time range of data being queried. Results will include all conversations that had activity during the interval. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this AsyncConversationQuery.
        :type: str
        """
        
        self._interval = interval

    @property
    def limit(self):
        """
        Gets the limit of this AsyncConversationQuery.
        Specify number of results to be returned

        :return: The limit of this AsyncConversationQuery.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this AsyncConversationQuery.
        Specify number of results to be returned

        :param limit: The limit of this AsyncConversationQuery.
        :type: int
        """
        
        self._limit = limit

    @property
    def start_of_day_interval_matching(self):
        """
        Gets the start_of_day_interval_matching of this AsyncConversationQuery.
        Add a filter to only include conversations that started after the beginning of the interval start date (UTC)

        :return: The start_of_day_interval_matching of this AsyncConversationQuery.
        :rtype: bool
        """
        return self._start_of_day_interval_matching

    @start_of_day_interval_matching.setter
    def start_of_day_interval_matching(self, start_of_day_interval_matching):
        """
        Sets the start_of_day_interval_matching of this AsyncConversationQuery.
        Add a filter to only include conversations that started after the beginning of the interval start date (UTC)

        :param start_of_day_interval_matching: The start_of_day_interval_matching of this AsyncConversationQuery.
        :type: bool
        """
        
        self._start_of_day_interval_matching = start_of_day_interval_matching

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmHistoricalDataUploadRequestStatusTopicDateTime(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmHistoricalDataUploadRequestStatusTopicDateTime - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'i_millis': 'int',
            'before_now': 'bool',
            'after_now': 'bool',
            'equal_now': 'bool'
        }

        self.attribute_map = {
            'i_millis': 'iMillis',
            'before_now': 'beforeNow',
            'after_now': 'afterNow',
            'equal_now': 'equalNow'
        }

        self._i_millis = None
        self._before_now = None
        self._after_now = None
        self._equal_now = None

    @property
    def i_millis(self):
        """
        Gets the i_millis of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :return: The i_millis of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :rtype: int
        """
        return self._i_millis

    @i_millis.setter
    def i_millis(self, i_millis):
        """
        Sets the i_millis of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :param i_millis: The i_millis of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :type: int
        """
        
        self._i_millis = i_millis

    @property
    def before_now(self):
        """
        Gets the before_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :return: The before_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :rtype: bool
        """
        return self._before_now

    @before_now.setter
    def before_now(self, before_now):
        """
        Sets the before_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :param before_now: The before_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :type: bool
        """
        
        self._before_now = before_now

    @property
    def after_now(self):
        """
        Gets the after_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :return: The after_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :rtype: bool
        """
        return self._after_now

    @after_now.setter
    def after_now(self, after_now):
        """
        Sets the after_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :param after_now: The after_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :type: bool
        """
        
        self._after_now = after_now

    @property
    def equal_now(self):
        """
        Gets the equal_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :return: The equal_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :rtype: bool
        """
        return self._equal_now

    @equal_now.setter
    def equal_now(self, equal_now):
        """
        Sets the equal_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.


        :param equal_now: The equal_now of this WfmHistoricalDataUploadRequestStatusTopicDateTime.
        :type: bool
        """
        
        self._equal_now = equal_now

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuAsyncAgentSchedulesSearchResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuAsyncAgentSchedulesSearchResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status': 'str',
            'operation_id': 'str',
            'result': 'BuAgentSchedulesSearchResponse',
            'progress': 'int',
            'download_url': 'str'
        }

        self.attribute_map = {
            'status': 'status',
            'operation_id': 'operationId',
            'result': 'result',
            'progress': 'progress',
            'download_url': 'downloadUrl'
        }

        self._status = None
        self._operation_id = None
        self._result = None
        self._progress = None
        self._download_url = None

    @property
    def status(self):
        """
        Gets the status of this BuAsyncAgentSchedulesSearchResponse.
        The status of the operation

        :return: The status of this BuAsyncAgentSchedulesSearchResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this BuAsyncAgentSchedulesSearchResponse.
        The status of the operation

        :param status: The status of this BuAsyncAgentSchedulesSearchResponse.
        :type: str
        """
        allowed_values = ["Processing", "Complete", "Canceled", "Error"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def operation_id(self):
        """
        Gets the operation_id of this BuAsyncAgentSchedulesSearchResponse.
        The ID for the operation

        :return: The operation_id of this BuAsyncAgentSchedulesSearchResponse.
        :rtype: str
        """
        return self._operation_id

    @operation_id.setter
    def operation_id(self, operation_id):
        """
        Sets the operation_id of this BuAsyncAgentSchedulesSearchResponse.
        The ID for the operation

        :param operation_id: The operation_id of this BuAsyncAgentSchedulesSearchResponse.
        :type: str
        """
        
        self._operation_id = operation_id

    @property
    def result(self):
        """
        Gets the result of this BuAsyncAgentSchedulesSearchResponse.
        The result of the operation.  Null unless status == Complete

        :return: The result of this BuAsyncAgentSchedulesSearchResponse.
        :rtype: BuAgentSchedulesSearchResponse
        """
        return self._result

    @result.setter
    def result(self, result):
        """
        Sets the result of this BuAsyncAgentSchedulesSearchResponse.
        The result of the operation.  Null unless status == Complete

        :param result: The result of this BuAsyncAgentSchedulesSearchResponse.
        :type: BuAgentSchedulesSearchResponse
        """
        
        self._result = result

    @property
    def progress(self):
        """
        Gets the progress of this BuAsyncAgentSchedulesSearchResponse.
        Percent progress for the operation

        :return: The progress of this BuAsyncAgentSchedulesSearchResponse.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """
        Sets the progress of this BuAsyncAgentSchedulesSearchResponse.
        Percent progress for the operation

        :param progress: The progress of this BuAsyncAgentSchedulesSearchResponse.
        :type: int
        """
        
        self._progress = progress

    @property
    def download_url(self):
        """
        Gets the download_url of this BuAsyncAgentSchedulesSearchResponse.
        The URL from which to download the result if it is too large to pass directly

        :return: The download_url of this BuAsyncAgentSchedulesSearchResponse.
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """
        Sets the download_url of this BuAsyncAgentSchedulesSearchResponse.
        The URL from which to download the result if it is too large to pass directly

        :param download_url: The download_url of this BuAsyncAgentSchedulesSearchResponse.
        :type: str
        """
        
        self._download_url = download_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PatchUser(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PatchUser - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'acd_auto_answer': 'bool',
            'certifications': 'list[str]',
            'biography': 'Biography',
            'employer_info': 'EmployerInfo'
        }

        self.attribute_map = {
            'id': 'id',
            'acd_auto_answer': 'acdAutoAnswer',
            'certifications': 'certifications',
            'biography': 'biography',
            'employer_info': 'employerInfo'
        }

        self._id = None
        self._acd_auto_answer = None
        self._certifications = None
        self._biography = None
        self._employer_info = None

    @property
    def id(self):
        """
        Gets the id of this PatchUser.
        The globally unique identifier for the object.

        :return: The id of this PatchUser.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PatchUser.
        The globally unique identifier for the object.

        :param id: The id of this PatchUser.
        :type: str
        """
        
        self._id = id

    @property
    def acd_auto_answer(self):
        """
        Gets the acd_auto_answer of this PatchUser.
        The value that denotes if acdAutoAnswer is set on the user

        :return: The acd_auto_answer of this PatchUser.
        :rtype: bool
        """
        return self._acd_auto_answer

    @acd_auto_answer.setter
    def acd_auto_answer(self, acd_auto_answer):
        """
        Sets the acd_auto_answer of this PatchUser.
        The value that denotes if acdAutoAnswer is set on the user

        :param acd_auto_answer: The acd_auto_answer of this PatchUser.
        :type: bool
        """
        
        self._acd_auto_answer = acd_auto_answer

    @property
    def certifications(self):
        """
        Gets the certifications of this PatchUser.


        :return: The certifications of this PatchUser.
        :rtype: list[str]
        """
        return self._certifications

    @certifications.setter
    def certifications(self, certifications):
        """
        Sets the certifications of this PatchUser.


        :param certifications: The certifications of this PatchUser.
        :type: list[str]
        """
        
        self._certifications = certifications

    @property
    def biography(self):
        """
        Gets the biography of this PatchUser.


        :return: The biography of this PatchUser.
        :rtype: Biography
        """
        return self._biography

    @biography.setter
    def biography(self, biography):
        """
        Sets the biography of this PatchUser.


        :param biography: The biography of this PatchUser.
        :type: Biography
        """
        
        self._biography = biography

    @property
    def employer_info(self):
        """
        Gets the employer_info of this PatchUser.


        :return: The employer_info of this PatchUser.
        :rtype: EmployerInfo
        """
        return self._employer_info

    @employer_info.setter
    def employer_info(self, employer_info):
        """
        Sets the employer_info of this PatchUser.


        :param employer_info: The employer_info of this PatchUser.
        :type: EmployerInfo
        """
        
        self._employer_info = employer_info

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationVideoEventTopicParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationVideoEventTopicParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'user_id': 'str',
            'external_contact_id': 'str',
            'external_organization_id': 'str',
            'name': 'str',
            'queue_id': 'str',
            'group_id': 'str',
            'team_id': 'str',
            'purpose': 'str',
            'consult_participant_id': 'str',
            'address': 'str',
            'wrapup_required': 'bool',
            'wrapup_expected': 'bool',
            'wrapup_prompt': 'str',
            'wrapup_timeout_ms': 'int',
            'wrapup': 'QueueConversationVideoEventTopicWrapup',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'conversation_routing_data': 'QueueConversationVideoEventTopicConversationRoutingData',
            'alerting_timeout_ms': 'int',
            'monitored_participant_id': 'str',
            'coached_participant_id': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'attributes': 'dict(str, str)',
            'calls': 'list[QueueConversationVideoEventTopicCall]',
            'callbacks': 'list[QueueConversationVideoEventTopicCallback]',
            'chats': 'list[QueueConversationVideoEventTopicChat]',
            'cobrowsesessions': 'list[QueueConversationVideoEventTopicCobrowse]',
            'emails': 'list[QueueConversationVideoEventTopicEmail]',
            'messages': 'list[QueueConversationVideoEventTopicMessage]',
            'screenshares': 'list[QueueConversationVideoEventTopicScreenshare]',
            'social_expressions': 'list[QueueConversationVideoEventTopicSocialExpression]',
            'videos': 'list[QueueConversationVideoEventTopicVideo]',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'user_id': 'userId',
            'external_contact_id': 'externalContactId',
            'external_organization_id': 'externalOrganizationId',
            'name': 'name',
            'queue_id': 'queueId',
            'group_id': 'groupId',
            'team_id': 'teamId',
            'purpose': 'purpose',
            'consult_participant_id': 'consultParticipantId',
            'address': 'address',
            'wrapup_required': 'wrapupRequired',
            'wrapup_expected': 'wrapupExpected',
            'wrapup_prompt': 'wrapupPrompt',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup': 'wrapup',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'conversation_routing_data': 'conversationRoutingData',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'monitored_participant_id': 'monitoredParticipantId',
            'coached_participant_id': 'coachedParticipantId',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'attributes': 'attributes',
            'calls': 'calls',
            'callbacks': 'callbacks',
            'chats': 'chats',
            'cobrowsesessions': 'cobrowsesessions',
            'emails': 'emails',
            'messages': 'messages',
            'screenshares': 'screenshares',
            'social_expressions': 'socialExpressions',
            'videos': 'videos',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._connected_time = None
        self._end_time = None
        self._user_id = None
        self._external_contact_id = None
        self._external_organization_id = None
        self._name = None
        self._queue_id = None
        self._group_id = None
        self._team_id = None
        self._purpose = None
        self._consult_participant_id = None
        self._address = None
        self._wrapup_required = None
        self._wrapup_expected = None
        self._wrapup_prompt = None
        self._wrapup_timeout_ms = None
        self._wrapup = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._conversation_routing_data = None
        self._alerting_timeout_ms = None
        self._monitored_participant_id = None
        self._coached_participant_id = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._attributes = None
        self._calls = None
        self._callbacks = None
        self._chats = None
        self._cobrowsesessions = None
        self._emails = None
        self._messages = None
        self._screenshares = None
        self._social_expressions = None
        self._videos = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationVideoEventTopicParticipant.


        :return: The id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationVideoEventTopicParticipant.


        :param id: The id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationVideoEventTopicParticipant.


        :return: The connected_time of this QueueConversationVideoEventTopicParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationVideoEventTopicParticipant.


        :param connected_time: The connected_time of this QueueConversationVideoEventTopicParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this QueueConversationVideoEventTopicParticipant.


        :return: The end_time of this QueueConversationVideoEventTopicParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this QueueConversationVideoEventTopicParticipant.


        :param end_time: The end_time of this QueueConversationVideoEventTopicParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def user_id(self):
        """
        Gets the user_id of this QueueConversationVideoEventTopicParticipant.


        :return: The user_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this QueueConversationVideoEventTopicParticipant.


        :param user_id: The user_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def external_contact_id(self):
        """
        Gets the external_contact_id of this QueueConversationVideoEventTopicParticipant.


        :return: The external_contact_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._external_contact_id

    @external_contact_id.setter
    def external_contact_id(self, external_contact_id):
        """
        Sets the external_contact_id of this QueueConversationVideoEventTopicParticipant.


        :param external_contact_id: The external_contact_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._external_contact_id = external_contact_id

    @property
    def external_organization_id(self):
        """
        Gets the external_organization_id of this QueueConversationVideoEventTopicParticipant.


        :return: The external_organization_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._external_organization_id

    @external_organization_id.setter
    def external_organization_id(self, external_organization_id):
        """
        Sets the external_organization_id of this QueueConversationVideoEventTopicParticipant.


        :param external_organization_id: The external_organization_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._external_organization_id = external_organization_id

    @property
    def name(self):
        """
        Gets the name of this QueueConversationVideoEventTopicParticipant.


        :return: The name of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueueConversationVideoEventTopicParticipant.


        :param name: The name of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def queue_id(self):
        """
        Gets the queue_id of this QueueConversationVideoEventTopicParticipant.


        :return: The queue_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this QueueConversationVideoEventTopicParticipant.


        :param queue_id: The queue_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def group_id(self):
        """
        Gets the group_id of this QueueConversationVideoEventTopicParticipant.


        :return: The group_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """
        Sets the group_id of this QueueConversationVideoEventTopicParticipant.


        :param group_id: The group_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._group_id = group_id

    @property
    def team_id(self):
        """
        Gets the team_id of this QueueConversationVideoEventTopicParticipant.


        :return: The team_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._team_id

    @team_id.setter
    def team_id(self, team_id):
        """
        Sets the team_id of this QueueConversationVideoEventTopicParticipant.


        :param team_id: The team_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._team_id = team_id

    @property
    def purpose(self):
        """
        Gets the purpose of this QueueConversationVideoEventTopicParticipant.


        :return: The purpose of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this QueueConversationVideoEventTopicParticipant.


        :param purpose: The purpose of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def consult_participant_id(self):
        """
        Gets the consult_participant_id of this QueueConversationVideoEventTopicParticipant.


        :return: The consult_participant_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._consult_participant_id

    @consult_participant_id.setter
    def consult_participant_id(self, consult_participant_id):
        """
        Sets the consult_participant_id of this QueueConversationVideoEventTopicParticipant.


        :param consult_participant_id: The consult_participant_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._consult_participant_id = consult_participant_id

    @property
    def address(self):
        """
        Gets the address of this QueueConversationVideoEventTopicParticipant.


        :return: The address of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this QueueConversationVideoEventTopicParticipant.


        :param address: The address of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this QueueConversationVideoEventTopicParticipant.


        :return: The wrapup_required of this QueueConversationVideoEventTopicParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this QueueConversationVideoEventTopicParticipant.


        :param wrapup_required: The wrapup_required of this QueueConversationVideoEventTopicParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_expected(self):
        """
        Gets the wrapup_expected of this QueueConversationVideoEventTopicParticipant.


        :return: The wrapup_expected of this QueueConversationVideoEventTopicParticipant.
        :rtype: bool
        """
        return self._wrapup_expected

    @wrapup_expected.setter
    def wrapup_expected(self, wrapup_expected):
        """
        Sets the wrapup_expected of this QueueConversationVideoEventTopicParticipant.


        :param wrapup_expected: The wrapup_expected of this QueueConversationVideoEventTopicParticipant.
        :type: bool
        """
        
        self._wrapup_expected = wrapup_expected

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this QueueConversationVideoEventTopicParticipant.


        :return: The wrapup_prompt of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this QueueConversationVideoEventTopicParticipant.


        :param wrapup_prompt: The wrapup_prompt of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this QueueConversationVideoEventTopicParticipant.


        :return: The wrapup_timeout_ms of this QueueConversationVideoEventTopicParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this QueueConversationVideoEventTopicParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this QueueConversationVideoEventTopicParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationVideoEventTopicParticipant.


        :return: The wrapup of this QueueConversationVideoEventTopicParticipant.
        :rtype: QueueConversationVideoEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationVideoEventTopicParticipant.


        :param wrapup: The wrapup of this QueueConversationVideoEventTopicParticipant.
        :type: QueueConversationVideoEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this QueueConversationVideoEventTopicParticipant.


        :return: The start_acw_time of this QueueConversationVideoEventTopicParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this QueueConversationVideoEventTopicParticipant.


        :param start_acw_time: The start_acw_time of this QueueConversationVideoEventTopicParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this QueueConversationVideoEventTopicParticipant.


        :return: The end_acw_time of this QueueConversationVideoEventTopicParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this QueueConversationVideoEventTopicParticipant.


        :param end_acw_time: The end_acw_time of this QueueConversationVideoEventTopicParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this QueueConversationVideoEventTopicParticipant.


        :return: The conversation_routing_data of this QueueConversationVideoEventTopicParticipant.
        :rtype: QueueConversationVideoEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this QueueConversationVideoEventTopicParticipant.


        :param conversation_routing_data: The conversation_routing_data of this QueueConversationVideoEventTopicParticipant.
        :type: QueueConversationVideoEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this QueueConversationVideoEventTopicParticipant.


        :return: The alerting_timeout_ms of this QueueConversationVideoEventTopicParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this QueueConversationVideoEventTopicParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this QueueConversationVideoEventTopicParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def monitored_participant_id(self):
        """
        Gets the monitored_participant_id of this QueueConversationVideoEventTopicParticipant.


        :return: The monitored_participant_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._monitored_participant_id

    @monitored_participant_id.setter
    def monitored_participant_id(self, monitored_participant_id):
        """
        Sets the monitored_participant_id of this QueueConversationVideoEventTopicParticipant.


        :param monitored_participant_id: The monitored_participant_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._monitored_participant_id = monitored_participant_id

    @property
    def coached_participant_id(self):
        """
        Gets the coached_participant_id of this QueueConversationVideoEventTopicParticipant.


        :return: The coached_participant_id of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._coached_participant_id

    @coached_participant_id.setter
    def coached_participant_id(self, coached_participant_id):
        """
        Sets the coached_participant_id of this QueueConversationVideoEventTopicParticipant.


        :param coached_participant_id: The coached_participant_id of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._coached_participant_id = coached_participant_id

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this QueueConversationVideoEventTopicParticipant.


        :return: The screen_recording_state of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this QueueConversationVideoEventTopicParticipant.


        :param screen_recording_state: The screen_recording_state of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        allowed_values = ["REQUESTED", "ACTIVE", "PAUSED", "STOPPED", "ERROR", "TIMEOUT"]
        if screen_recording_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for screen_recording_state -> " + screen_recording_state)
            self._screen_recording_state = "outdated_sdk_version"
        else:
            self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this QueueConversationVideoEventTopicParticipant.


        :return: The flagged_reason of this QueueConversationVideoEventTopicParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this QueueConversationVideoEventTopicParticipant.


        :param flagged_reason: The flagged_reason of this QueueConversationVideoEventTopicParticipant.
        :type: str
        """
        
        self._flagged_reason = flagged_reason

    @property
    def attributes(self):
        """
        Gets the attributes of this QueueConversationVideoEventTopicParticipant.


        :return: The attributes of this QueueConversationVideoEventTopicParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this QueueConversationVideoEventTopicParticipant.


        :param attributes: The attributes of this QueueConversationVideoEventTopicParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def calls(self):
        """
        Gets the calls of this QueueConversationVideoEventTopicParticipant.


        :return: The calls of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicCall]
        """
        return self._calls

    @calls.setter
    def calls(self, calls):
        """
        Sets the calls of this QueueConversationVideoEventTopicParticipant.


        :param calls: The calls of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicCall]
        """
        
        self._calls = calls

    @property
    def callbacks(self):
        """
        Gets the callbacks of this QueueConversationVideoEventTopicParticipant.


        :return: The callbacks of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicCallback]
        """
        return self._callbacks

    @callbacks.setter
    def callbacks(self, callbacks):
        """
        Sets the callbacks of this QueueConversationVideoEventTopicParticipant.


        :param callbacks: The callbacks of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicCallback]
        """
        
        self._callbacks = callbacks

    @property
    def chats(self):
        """
        Gets the chats of this QueueConversationVideoEventTopicParticipant.


        :return: The chats of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicChat]
        """
        return self._chats

    @chats.setter
    def chats(self, chats):
        """
        Sets the chats of this QueueConversationVideoEventTopicParticipant.


        :param chats: The chats of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicChat]
        """
        
        self._chats = chats

    @property
    def cobrowsesessions(self):
        """
        Gets the cobrowsesessions of this QueueConversationVideoEventTopicParticipant.


        :return: The cobrowsesessions of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicCobrowse]
        """
        return self._cobrowsesessions

    @cobrowsesessions.setter
    def cobrowsesessions(self, cobrowsesessions):
        """
        Sets the cobrowsesessions of this QueueConversationVideoEventTopicParticipant.


        :param cobrowsesessions: The cobrowsesessions of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicCobrowse]
        """
        
        self._cobrowsesessions = cobrowsesessions

    @property
    def emails(self):
        """
        Gets the emails of this QueueConversationVideoEventTopicParticipant.


        :return: The emails of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicEmail]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """
        Sets the emails of this QueueConversationVideoEventTopicParticipant.


        :param emails: The emails of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicEmail]
        """
        
        self._emails = emails

    @property
    def messages(self):
        """
        Gets the messages of this QueueConversationVideoEventTopicParticipant.


        :return: The messages of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicMessage]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this QueueConversationVideoEventTopicParticipant.


        :param messages: The messages of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicMessage]
        """
        
        self._messages = messages

    @property
    def screenshares(self):
        """
        Gets the screenshares of this QueueConversationVideoEventTopicParticipant.


        :return: The screenshares of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicScreenshare]
        """
        return self._screenshares

    @screenshares.setter
    def screenshares(self, screenshares):
        """
        Sets the screenshares of this QueueConversationVideoEventTopicParticipant.


        :param screenshares: The screenshares of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicScreenshare]
        """
        
        self._screenshares = screenshares

    @property
    def social_expressions(self):
        """
        Gets the social_expressions of this QueueConversationVideoEventTopicParticipant.


        :return: The social_expressions of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicSocialExpression]
        """
        return self._social_expressions

    @social_expressions.setter
    def social_expressions(self, social_expressions):
        """
        Sets the social_expressions of this QueueConversationVideoEventTopicParticipant.


        :param social_expressions: The social_expressions of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicSocialExpression]
        """
        
        self._social_expressions = social_expressions

    @property
    def videos(self):
        """
        Gets the videos of this QueueConversationVideoEventTopicParticipant.


        :return: The videos of this QueueConversationVideoEventTopicParticipant.
        :rtype: list[QueueConversationVideoEventTopicVideo]
        """
        return self._videos

    @videos.setter
    def videos(self, videos):
        """
        Sets the videos of this QueueConversationVideoEventTopicParticipant.


        :param videos: The videos of this QueueConversationVideoEventTopicParticipant.
        :type: list[QueueConversationVideoEventTopicVideo]
        """
        
        self._videos = videos

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationVideoEventTopicParticipant.


        :return: The additional_properties of this QueueConversationVideoEventTopicParticipant.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationVideoEventTopicParticipant.


        :param additional_properties: The additional_properties of this QueueConversationVideoEventTopicParticipant.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimError - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status': 'str',
            'scim_type': 'str',
            'detail': 'str',
            'schemas': 'list[str]'
        }

        self.attribute_map = {
            'status': 'status',
            'scim_type': 'scimType',
            'detail': 'detail',
            'schemas': 'schemas'
        }

        self._status = None
        self._scim_type = None
        self._detail = None
        self._schemas = None

    @property
    def status(self):
        """
        Gets the status of this ScimError.
        The HTTP status code returned for the SCIM error.

        :return: The status of this ScimError.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ScimError.
        The HTTP status code returned for the SCIM error.

        :param status: The status of this ScimError.
        :type: str
        """
        
        self._status = status

    @property
    def scim_type(self):
        """
        Gets the scim_type of this ScimError.
        The type of SCIM error when httpStatus is a \"400\" error.

        :return: The scim_type of this ScimError.
        :rtype: str
        """
        return self._scim_type

    @scim_type.setter
    def scim_type(self, scim_type):
        """
        Sets the scim_type of this ScimError.
        The type of SCIM error when httpStatus is a \"400\" error.

        :param scim_type: The scim_type of this ScimError.
        :type: str
        """
        allowed_values = ["invalidFilter", "tooMany", "uniqueness", "mutability", "invalidSyntax", "invalidPath", "noTarget", "invalidValue", "invalidVers", "sensitive"]
        if scim_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for scim_type -> " + scim_type)
            self._scim_type = "outdated_sdk_version"
        else:
            self._scim_type = scim_type

    @property
    def detail(self):
        """
        Gets the detail of this ScimError.
        The detailed description of the SCIM error.

        :return: The detail of this ScimError.
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """
        Sets the detail of this ScimError.
        The detailed description of the SCIM error.

        :param detail: The detail of this ScimError.
        :type: str
        """
        
        self._detail = detail

    @property
    def schemas(self):
        """
        Gets the schemas of this ScimError.
        The list of schemas for the SCIM error.

        :return: The schemas of this ScimError.
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """
        Sets the schemas of this ScimError.
        The list of schemas for the SCIM error.

        :param schemas: The schemas of this ScimError.
        :type: list[str]
        """
        
        self._schemas = schemas

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

